package com.usky.fire.service.impl;

import cn.hutool.core.date.DateUnit;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.fire.domain.AlarmFire;
import com.usky.fire.domain.BaseUserCompany;
import com.usky.fire.domain.BscEnterpriseAutonomy;
import com.usky.fire.domain.DemInspectList;
import com.usky.fire.mapper.DemInspectListMapper;
import com.usky.fire.service.DemInspectListService;
import com.usky.common.mybatis.core.AbstractCrudService;
import org.apache.commons.lang.time.DateFormatUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.usky.fire.service.*;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.UUID;

/**
 * <p>
 * 督察单 服务实现类
 * </p>
 *
 * @author ZYJ
 * @since 2022-12-28
 */
@Service
public class DemInspectListServiceImpl extends AbstractCrudService<DemInspectListMapper, DemInspectList> implements DemInspectListService {
    @Autowired
    private DemInspectListService demInspectListService;

    @Autowired
    private AlarmFireService alarmFireService;

    @Transactional
    @Override
    //先判断处理状态为未处理的告警,然后再判断告警时间距离当前时间超过半小时
    public void demInspectAutoTask() {
        //未处置电子督察单
        LambdaQueryWrapper<AlarmFire> QueryWrapper = Wrappers.lambdaQuery();
        List<String> alarmTypeList = new ArrayList<>();
        alarmTypeList.add("2");
        alarmTypeList.add("4");
        QueryWrapper.select(AlarmFire::getDeviceCode,AlarmFire::getId,AlarmFire::getCompanyId)
                .in(AlarmFire::getAlarmType,alarmTypeList)
                .eq(AlarmFire::getHandlingStatus, 0)
                .lt(AlarmFire::getAlarmTime, LocalDateTime.now().minusMinutes(30).format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")));
        List<AlarmFire> list = alarmFireService.list(QueryWrapper);
        if(CollectionUtils.isNotEmpty(list)){
            for(int i=0;i<list.size();i++){
                DemInspectList demInspectList = new DemInspectList();
                UUID uuid = UUID.randomUUID();
                String uuidStr = uuid.toString();
                demInspectList.setInspectCode(uuidStr.replaceAll("-",""));
                demInspectList.setDeviceId(list.get(i).getDeviceCode());
                demInspectList.setAlarmId(list.get(i).getId());
                demInspectList.setCompanyId(list.get(i).getCompanyId());
                //2 待处置
                demInspectList.setHandlingStatus(2);
                demInspectList.setCreator("闵行消防支队");
                demInspectList.setCreateTime(LocalDateTime.now());

                this.save(demInspectList);

            }
        }

        //超时未处置电子督察单
        LambdaQueryWrapper<DemInspectList> QueryList = Wrappers.lambdaQuery();
        QueryList.eq(DemInspectList::getHandlingStatus,2)
                .lt(DemInspectList::getCreateTime,LocalDateTime.now().minusMinutes(30).format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")));
        List<DemInspectList> list1 = this.list(QueryList);
        if(CollectionUtils.isNotEmpty(list1)){
            for(int j=0;j<list1.size();j++){
                //3 超时未处置
                list1.get(j).setHandlingStatus(3);
                this.updateById(list1.get(j));
            }
        }

    }
}
